# Copyright (c) 2019 Stephen Bunn <stephen@bunn.io>
# ISC License <https://choosealicense.com/licenses/isc>

from . import contrib, handlers, __version__
from .constants import CONFIG_KEY
from ._file_config import var, config, to_dict, validate, from_dict, make_config
from .schema_builder import Regex, build_schema

__all__ = [
    "__version__",
    "contrib",
    "handlers",
    "CONFIG_KEY",
    "var",
    "config",
    "to_dict",
    "validate",
    "from_dict",
    "make_config",
    "Regex",
    "build_schema",
]



# Copyright (c) 2019 Stephen Bunn <stephen@bunn.io>
# ISC License <https://choosealicense.com/licenses/isc>

from .ini import INIHandler
from .xml import XMLHandler
from .json import JSONHandler
from .toml import TOMLHandler
from .yaml import YAMLHandler
from .pickle import PickleHandler
from .msgpack import MsgpackHandler

__all__ = [
    "INIHandler",
    "XMLHandler",
    "JSONHandler",
    "TOMLHandler",
    "YAMLHandler",
    "PickleHandler",
    "MsgpackHandler",
]



# Copyright (c) 2019 Stephen Bunn <stephen@bunn.io>
# ISC License <https://choosealicense.com/licenses/isc>

# used for referencing metadata in built classes
CONFIG_KEY = "__file_config_metadata"
# used for referencing the custom regex type required for schema building
REGEX_TYPE_NAME = "__file_config_regex"
